use std::collections::{BTreeMap, HashMap};

/// An item which stores known certificates
pub trait CertificateStore: Send + Sync {
    fn get_certificate(&self, host: &str) -> Option<String>;
    fn insert_certificate(&mut self, host: &str, fingerprint: &str) -> Option<String>;
    fn contains_certificate(&self, host: &str) -> bool;
}

impl CertificateStore for HashMap<String, String> {
    fn get_certificate(&self, host: &str) -> Option<String> {
        self.get(host).cloned()
    }

    fn insert_certificate(&mut self, host: &str, fingerprint: &str) -> Option<String> {
        self.insert(host.to_string(), fingerprint.to_string())
    }

    fn contains_certificate(&self, host: &str) -> bool {
        self.contains_key(host)
    }
}

impl CertificateStore for BTreeMap<String, String> {
    fn get_certificate(&self, host: &str) -> Option<String> {
        self.get(host).cloned()
    }

    fn insert_certificate(&mut self, host: &str, fingerprint: &str) -> Option<String> {
        self.insert(host.to_string(), fingerprint.to_string())
    }

    fn contains_certificate(&self, host: &str) -> bool {
        self.contains_key(host)
    }
}
